==> prestashop_1.5.2.0.zip: prestashop/modules/statsregistrations/translations/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statsregistrations}prestashop>statsregistrations_8b15fc6468c919d299f9a601b61b95fc'] = 'Kundenkonten';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_089c9061407fd978366e78b6ad1d0111'] = 'Anzeige des Fortschritts der Kundenregistrierung';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_75abad0b891bc086fd4837e81a8c488a'] = 'Besucher, die bei der Registrierung aufgehört haben:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_4e4f3af3fb18136b8eec4b77f25095ce'] = 'Besucher, die direkt nach der Anmeldung eine Bestellung vorgenommen haben:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_a751e9cc4ed4c7585ecc0d97781cb48a'] = 'Kundenkonten insgesamt:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_998e4c5c80f27dec552e99dfed34889a'] = 'CSV-Export';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guide';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_fba0e64541196123bbf8e3737bf9287b'] = 'Anzahl der erstellten Kundenkonten';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_a286f4eaef73a0b4f955c42b84472444'] = 'Die Gesamtzahl der erstellten Konten ist an sich keine wichtige Information. Es ist allerdings interessant, die Zahl der Eröffnungen über die Zeit gesehen zu analysieren. Dies sagt aus, ob die Dinge auf dem richtigen Weg sind.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_57a6f41a27c9baa5b402d30e97d4c1e8'] = 'Die richtige Reaktion auf die Entwicklung der Registrierungen';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_f123e4522d188fba4cbe1dc58034f95c'] = 'Wenn Sie Ihren Shop laufen lassen, ohne etwas zu ändern, sollte die Anzahl der Kunden-Registrierungen stabil bleiben oder leicht rückläufig sein.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_f8426f15c536f4341dbeb4d806f76167'] = 'Ein signifikanter Anstieg oder Rückgang zeigt, dass es wahrscheinlich eine Änderung in Ihrem Shop gegeben hat, Sie müssensie identifizieren, um herauszufinden, ob diese Änderung die Zahl der Anmeldungen zurückgehen lässt oder fortfahren, wenn dies vorteilhaft ist.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_48ad285c9749cc74821048c49aea6a50'] = 'Hier ist eine Zusammenfassung dessen, was die Eröffnung von Kundenkonten beeinflusst:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_cd0d9770ca8ee818040fa3453fbaa1ae'] = 'Eine Werbekampagne kann eine größere Anzahl von Besuchern anziehen. Eine sich daraus ergebende Zunahme von Kundenkonten, hängt von der \"Qualität\" der Kampagne ab: gezielte Werbung kann effektiver sein als breit angelegte Werbung.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_b2eceb617c0a86e0dbe5d844f0ec353e'] = 'Sonderangebote, Verkäufe, oder Wettbewerbe schaffen mehr Aufmerksamkeit und Neugier, und halten Ihren Shop nicht nur lebendig, sondern erhöhen auch die Besucherzahl. Auf diese Weise können Sie impulsive Käufer zum Kaufen animieren.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_52a6042899eefb32fcd219672c0c7179'] = 'Design und Benutzerfreundlichkeit sind heute wichtiger denn je: ein schlecht gewähltes oder schwer verständliches grafisches Thema kann Besuchern die Lust zum Kaufen nehmen. Sie müssen die richtige Balance zwischen einem innovativen Design und einer leichten Surfbarkeit für Besucher finden. Korrekte Rechtschreibung und Klarheit wecken ebenso mehr das Kundenvertrauen in Ihren Shop.';

==> prestashop_1.5.3.1.zip: prestashop/modules/statsregistrations/translations/de.php <==
<?php

global $_MODULE;
$_MODULE = array();

$_MODULE['<{statsregistrations}prestashop>statsregistrations_75abad0b891bc086fd4837e81a8c488a'] = 'Besucher, die bei der Registrierung aufgehört haben:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_a286f4eaef73a0b4f955c42b84472444'] = 'Die Gesamtzahl der erstellten Konten ist an sich keine wichtige Information. Es ist allerdings interessant, die Zahl der Eröffnungen über die Zeit gesehen zu analysieren. Dies sagt aus, ob die Dinge auf dem richtigen Weg sind.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_f123e4522d188fba4cbe1dc58034f95c'] = 'Wenn Sie Ihren Shop laufen lassen, ohne etwas zu ändern, sollte die Anzahl der Kunden-Registrierungen stabil bleiben oder leicht rückläufig sein.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_48ad285c9749cc74821048c49aea6a50'] = 'Hier ist eine Zusammenfassung dessen, was die Eröffnung von Kundenkonten beeinflusst:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_cd0d9770ca8ee818040fa3453fbaa1ae'] = 'Eine Werbekampagne kann eine größere Anzahl von Besuchern anziehen. Eine sich daraus ergebende Zunahme von Kundenkonten, hängt von der \\"Qualität\\" der Kampagne ab: gezielte Werbung kann effektiver sein als breit angelegte Werbung.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_8b15fc6468c919d299f9a601b61b95fc'] = 'Kundenkonten';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guide';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_57a6f41a27c9baa5b402d30e97d4c1e8'] = 'Die richtige Reaktion auf die Entwicklung der Registrierungen';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_f8426f15c536f4341dbeb4d806f76167'] = 'Ein signifikanter Anstieg oder Rückgang zeigt, dass es wahrscheinlich eine Änderung in Ihrem Shop gegeben hat, Sie müssensie identifizieren, um herauszufinden, ob diese Änderung die Zahl der Anmeldungen zurückgehen lässt oder fortfahren, wenn dies vorteilhaft ist.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_52a6042899eefb32fcd219672c0c7179'] = 'Design und Benutzerfreundlichkeit sind heute wichtiger denn je: ein schlecht gewähltes oder schwer verständliches grafisches Thema kann Besuchern die Lust zum Kaufen nehmen. Sie müssen die richtige Balance zwischen einem innovativen Design und einer leichten Surfbarkeit für Besucher finden. Korrekte Rechtschreibung und Klarheit wecken ebenso mehr das Kundenvertrauen in Ihren Shop.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_089c9061407fd978366e78b6ad1d0111'] = 'Anzeige des Fortschritts der Kundenregistrierung';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_4e4f3af3fb18136b8eec4b77f25095ce'] = 'Besucher, die direkt nach der Anmeldung eine Bestellung vorgenommen haben:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_998e4c5c80f27dec552e99dfed34889a'] = 'CSV-Export';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_fba0e64541196123bbf8e3737bf9287b'] = 'Anzahl der erstellten Kundenkonten';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_b2eceb617c0a86e0dbe5d844f0ec353e'] = 'Sonderangebote, Verkäufe, oder Wettbewerbe schaffen mehr Aufmerksamkeit und Neugier, und halten Ihren Shop nicht nur lebendig, sondern erhöhen auch die Besucherzahl. Auf diese Weise können Sie impulsive Käufer zum Kaufen animieren.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_a751e9cc4ed4c7585ecc0d97781cb48a'] = 'Kundenkonten insgesamt:';
